@@ -34,7 +34,6 @@
 #include <EventViews/ViewCalendar>
 
 #include <QDialog>
-#include <QStringList>
 
 class Ui_resourceManagement;
 
@@ -63,9 +62,9 @@ private:
      */
     void showDetails(const KLDAP::LdapObject &, const KLDAP::LdapClient &client);
 
-    QItemSelectionModel *selectionModel;
+    QItemSelectionModel *selectionModel = nullptr;
 
-private Q_SLOTS:
+private:
     /* A new searchString is entered
      *
      */
@@ -86,14 +85,14 @@ private Q_SLOTS:
 private:
     void readConfig();
     void writeConfig();
-    CalendarSupport::FreeBusyItemModel *mModel;
+    CalendarSupport::FreeBusyItemModel *mModel = nullptr;
     CalendarSupport::FreeBusyCalendar mFreebusyCalendar;
     ResourceItem::Ptr mOwnerItem;
     ResourceItem::Ptr mSelectedItem;
     EventViews::ViewCalendar::Ptr mFbCalendar;
-    Ui_resourceManagement *mUi;
+    Ui_resourceManagement *mUi = nullptr;
     QMap<QModelIndex, KCalCore::Event::Ptr> mFbEvent;
-    EventViews::AgendaView *mAgendaView;
+    EventViews::AgendaView *mAgendaView = nullptr;
 };
 }
 #endif // RESOURCEMANAGEMENT_H
